;; Generated package description from wrap-search.el  -*- no-byte-compile: t -*-
(define-package "wrap-search" "4.14.10.0.20240409.112534" "wrapped, non-incremental search" 'nil :commit "982f8941af5993721bc899de2efccb4026276441" :authors '(("Emanuel Berg" . "incal@dataswamp.org")) :maintainer '("Emanuel Berg" . "incal@dataswamp.org") :keywords '("matching") :url "https://dataswamp.org/~incal/emacs-init/wrap-search.el")
